#!/bin/bash

####################################################################
#					KOOLDOCK REFLECTIVE-ICONS SCRIPT							 #
#																						 #
#			This script is distributed under GPL license.				 #
#																						 #
#Script by		:	Adrian Antonana (a.antonana@gmail.com)				 #
#Version			:	1.0															 #
#Last update	:	06/27/2008													 #
#Dependencies	:	You need "ImageMagick" installed in your system  #
#						to run this script.										 #
####################################################################

THEME_DIR="theme"
REFLECT_DIR="reflect"
BASE_DIR="base"
ICON_DIR="icons"
CONV_PATH=""
COMP_PATH=""



clear
echo -e "\tKooldock reflective-icon script"
echo -e "\t-------------------------------\n"

#Looking for convert

echo -n "Looking for convert... "
CONV_PATH=`which convert 2> /dev/null`
if [ "$CONV_PATH" != "" ]; then
	echo "$CONV_PATH"
else
	echo "not found."
	echo -e "\nDependencies not met. Please read the README file section \"Dependencies\"."
	exit 1
fi

#Looking for composite

echo -n "Looking for composite... "
COMP_PATH=`which composite 2> /dev/null`
if [ "$COMP_PATH" != "" ]; then
	echo "$COMP_PATH"
else
	echo "not found."
	echo -e "\nDependencies not met. Please read the README file section \"Dependencies\"."
	exit 1
fi

#Removing existing files
rm -R "$REFLECT_DIR" 2> /dev/null
rm -R "$THEME_DIR" 2> /dev/null

echo -e "\nAll dependencies met."
echo -ne "\nMaking icon theme"


#Converting all icons to 106x106 pixels
mkdir "$THEME_DIR"
cd "$ICON_DIR"
for i in *; do
	$CONV_PATH "$i" -resize 106 "../$THEME_DIR/$i"
	echo -n "."
done
cd ".."

#Rotating 180
cd "$THEME_DIR"
mkdir "$REFLECT_DIR"

for i in *.png; do
	$CONV_PATH "$i" -rotate -180 "$REFLECT_DIR/$i"
	echo -n "."
done

#Crop&Flop
cd "$REFLECT_DIR"
for i in *; do
	$CONV_PATH "$i" -crop 106x24+0+3! "$i"
	$CONV_PATH "$i" -flop "$i"
	echo -n "."
done

#Change alpha to semi-transparent
for i in *; do
	$CONV_PATH "$i" -channel alpha -evaluate divide 2 "$i"
	echo -n "."
done

#Merge each icon with its reflection
cd ".."
for i in *.png; do
	$COMP_PATH -geometry +11+0 -compose src-over "$i" "../$BASE_DIR/base.png" "$i"
	$COMP_PATH -geometry +11+104 -compose src-over "$REFLECT_DIR/$i" "$i" "$i"
	echo -n "."
done

#Clean up
rm -R "$REFLECT_DIR"

echo -e "done!!\n\n"
echo "The new reflective-icons-theme is placed in the \"$THEME_DIR\" folder."

exit 0
